emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

master de15ca7: Fix typos


From: Mattias Engdegård
Subject: master de15ca7: Fix typos
Date: Thu, 18 Feb 2021 10:51:20 -0500 (EST)

branch: master
commit de15ca7d0065c5f77c88a90f4f14569886be3617
Author: Mattias Engdegård <mattiase@acm.org>
Commit: Mattias Engdegård <mattiase@acm.org>

    Fix typos
    
    * doc/lispref/display.texi (Size of Displayed Text):
    * doc/lispref/windows.texi (Buffer Display Action Functions):
    * etc/NEWS:
    * etc/ORG-NEWS (Org-Attach has been refactored and extended):
    * lisp/battery.el (display-battery-mode, battery--upower-subsribe):
    * lisp/calendar/parse-time.el:
    * lisp/dired-x.el:
    * lisp/emacs-lisp/chart.el (chart-sequece, chart-bar-quickie):
    * lisp/emacs-lisp/eldoc.el (eldoc-echo-area-use-multiline-p)
    (eldoc-documentation-strategy):
    * lisp/emacs-lisp/pcase.el (pcase--split-pred, pcase--u1):
    * lisp/gnus/gnus-search.el (gnus-search-expandable-keys)
    (gnus-search-parse-query, gnus-search-query-return-string)
    (gnus-search-imap, gnus-search-imap-search-command)
    (gnus-search-transform-expression):
    * lisp/gnus/nnselect.el:
    * lisp/isearch.el (isearch-lazy-count-format):
    * lisp/mh-e/mh-show.el (mh-show-msg):
    * lisp/net/dictionary-connection.el (dictionary-connection-open):
    * lisp/net/dictionary.el (dictionary-default-popup-strategy)
    (dictionary, dictionary-split-string, dictionary-do-select-dictionary)
    (dictionary-display-dictionarys, dictionary-search)
    (dictionary-tooltip-mode):
    * lisp/net/eudcb-macos-contacts.el (eudc-macos-contacts-set-server):
    * lisp/net/mailcap.el (mailcap-mime-data):
    * lisp/net/tramp-smb.el (tramp-smb-maybe-open-connection):
    * lisp/nxml/nxml-mode.el (nxml-mode):
    * lisp/progmodes/cc-engine.el:
    * lisp/progmodes/cperl-mode.el (cperl-mode)
    (cperl-fontify-syntaxically):
    * lisp/progmodes/flymake.el (flymake-diagnostic-functions):
    * lisp/progmodes/verilog-mode.el (verilog--supressed-warnings)
    (verilog-preprocess):
    * lisp/simple.el (self-insert-uses-region-functions):
    * lisp/textmodes/bibtex.el (bibtex-copy-summary-as-kill):
    * lisp/textmodes/texnfo-upd.el (texinfo-insert-master-menu-list):
    * src/dispnew.c:
    * src/font.c (Ffont_get):
    * src/indent.c (compute_motion):
    * src/process.c (init_process_emacs):
    * src/w32fns.c (deliver_wm_chars):
    * test/lisp/jsonrpc-tests.el (deferred-action-complex-tests):
    Fix typos in documentation, comments, and internal identifiers.
---
 doc/lispref/display.texi          |  2 +-
 doc/lispref/windows.texi          |  2 +-
 etc/NEWS                          |  2 +-
 etc/ORG-NEWS                      |  2 +-
 lisp/battery.el                   |  4 ++--
 lisp/calendar/parse-time.el       |  2 +-
 lisp/dired-x.el                   |  2 +-
 lisp/emacs-lisp/chart.el          |  6 +++---
 lisp/emacs-lisp/eldoc.el          |  4 ++--
 lisp/emacs-lisp/pcase.el          |  4 ++--
 lisp/gnus/gnus-search.el          | 16 ++++++++--------
 lisp/gnus/nnselect.el             |  2 +-
 lisp/isearch.el                   |  2 +-
 lisp/mh-e/mh-show.el              |  2 +-
 lisp/net/dictionary-connection.el |  6 +++---
 lisp/net/dictionary.el            | 20 ++++++++++----------
 lisp/net/eudcb-macos-contacts.el  |  2 +-
 lisp/net/mailcap.el               |  2 +-
 lisp/net/tramp-smb.el             |  2 +-
 lisp/nxml/nxml-mode.el            |  2 +-
 lisp/progmodes/cc-engine.el       |  2 +-
 lisp/progmodes/cperl-mode.el      |  6 +++---
 lisp/progmodes/flymake.el         |  2 +-
 lisp/progmodes/verilog-mode.el    |  4 ++--
 lisp/simple.el                    |  2 +-
 lisp/textmodes/bibtex.el          |  2 +-
 lisp/textmodes/texnfo-upd.el      |  2 +-
 src/dispnew.c                     |  2 +-
 src/font.c                        |  2 +-
 src/indent.c                      |  2 +-
 src/process.c                     |  2 +-
 src/w32fns.c                      |  2 +-
 test/lisp/jsonrpc-tests.el        |  2 +-
 33 files changed, 59 insertions(+), 59 deletions(-)

diff --git a/doc/lispref/display.texi b/doc/lispref/display.texi
index 93e935c..131ad2d 100644
--- a/doc/lispref/display.texi
+++ b/doc/lispref/display.texi
@@ -1997,7 +1997,7 @@ the beginning of the result if a multi-column character in
 
 If @var{ellipsis} is non-@code{nil}, it should be a string which will
 replace the end of @var{string} when it is truncated.  In this case,
-more charcaters will be removed from @var{string} to free enough space
+more characters will be removed from @var{string} to free enough space
 for @var{ellipsis} to fit within @var{width} columns.  However, if
 the display width of @var{string} is less than the display width of
 @var{ellipsis}, @var{ellipsis} will not be appended to the result.  If
diff --git a/doc/lispref/windows.texi b/doc/lispref/windows.texi
index f305d1a..c32d711 100644
--- a/doc/lispref/windows.texi
+++ b/doc/lispref/windows.texi
@@ -2557,7 +2557,7 @@ frame visible and, unless @var{alist} contains an
 This function tries to display @var{buffer} by finding a window
 that is displaying a buffer in a given mode.
 
-If @var{alist} contains a @code{mode} entry, its value specifes a
+If @var{alist} contains a @code{mode} entry, its value specifies a
 major mode (a symbol) or a list of major modes.  If @var{alist}
 contains no @code{mode} entry, the current major mode of @var{buffer}
 is used instead.  A window is a candidate if it displays a buffer
diff --git a/etc/NEWS b/etc/NEWS
index 7665d47..ee8a68a 100644
--- a/etc/NEWS
+++ b/etc/NEWS
@@ -1015,7 +1015,7 @@ separate buffer, or a tooltip.
 *** New user option 'eldoc-documentation-strategy'.
 The built-in choices available for this user option let users compose
 the results of 'eldoc-documentation-functions' in various ways, even
-if some of those functions are sychronous and some asynchchronous.
+if some of those functions are synchronous and some asynchronous.
 The user option replaces 'eldoc-documentation-function', which is now
 obsolete.
 
diff --git a/etc/ORG-NEWS b/etc/ORG-NEWS
index 2cae8b9..2b9cbf3 100644
--- a/etc/ORG-NEWS
+++ b/etc/ORG-NEWS
@@ -747,7 +747,7 @@ removed.
 For those who hate breaking changes, even though the changes are made
 to clean things up; fear not.  ATTACH_DIR will still continue to work.
 It's just not documented any longer.  When you get the chance, run the
-code above to clean things up anyways!
+code above to clean things up anyway!
 
 **** New hooks
 Two hooks are added to org-attach:
diff --git a/lisp/battery.el b/lisp/battery.el
index 77ad73d..59f6987 100644
--- a/lisp/battery.el
+++ b/lisp/battery.el
@@ -246,7 +246,7 @@ seconds."
        (add-to-list 'global-mode-string 'battery-mode-line-string t)
         (and (eq battery-status-function #'battery-upower)
              battery-upower-subscribe
-             (battery--upower-subsribe))
+             (battery--upower-subscribe))
        (setq battery-update-timer (run-at-time nil battery-update-interval
                                                 #'battery-update-handler))
        (battery-update))
@@ -634,7 +634,7 @@ Intended as a UPower PropertiesChanged signal handler."
   (mapc #'dbus-unregister-object battery--upower-signals)
   (setq battery--upower-signals ()))
 
-(defun battery--upower-subsribe ()
+(defun battery--upower-subscribe ()
   "Subscribe to UPower device change signals."
   (push (dbus-register-signal :system battery-upower-service
                               battery-upower-path
diff --git a/lisp/calendar/parse-time.el b/lisp/calendar/parse-time.el
index ba7418f..aa3236c 100644
--- a/lisp/calendar/parse-time.el
+++ b/lisp/calendar/parse-time.el
@@ -29,7 +29,7 @@
 
 ;; `parse-time-string' parses a time in a string and returns a list of
 ;; values, just like `decode-time', where unspecified elements in the
-;; string are returned as nil (except unspecfied DST is returned as -1).
+;; string are returned as nil (except unspecified DST is returned as -1).
 ;; `encode-time' may be applied on these values to obtain an internal
 ;; time value.
 
diff --git a/lisp/dired-x.el b/lisp/dired-x.el
index 5a52ecc..1199de1 100644
--- a/lisp/dired-x.el
+++ b/lisp/dired-x.el
@@ -447,7 +447,7 @@ If it is `no-dir', omitting is much faster, but you can 
only match
 against the non-directory part of the file name.  Set it to nil if you
 need to match the entire file name.")
 
-;; \017=^O for Omit - other packages can chose other control characters.
+;; \017=^O for Omit - other packages can choose other control characters.
 (defvar dired-omit-marker-char ?\017
   "Temporary marker used by Dired-Omit.
 Should never be used as marker by the user or other packages.")
diff --git a/lisp/emacs-lisp/chart.el b/lisp/emacs-lisp/chart.el
index 7d760ff..40c17b9 100644
--- a/lisp/emacs-lisp/chart.el
+++ b/lisp/emacs-lisp/chart.el
@@ -187,7 +187,7 @@ Make sure the width/height is correct."
    )
   "Class used to display an axis which represents different named items.")
 
-(defclass chart-sequece ()
+(defclass chart-sequence ()
   ((data :initarg :data
         :initform nil)
    (name :initarg :name
@@ -583,12 +583,12 @@ SORT-PRED if desired."
                           ))
        (iv (eq dir 'vertical)))
     (chart-add-sequence nc
-                       (make-instance 'chart-sequece
+                       (make-instance 'chart-sequence
                                       :data namelst
                                       :name nametitle)
                        (if iv 'x-axis 'y-axis))
     (chart-add-sequence nc
-                       (make-instance 'chart-sequece
+                       (make-instance 'chart-sequence
                                       :data numlst
                                       :name numtitle)
                        (if iv 'y-axis 'x-axis))
diff --git a/lisp/emacs-lisp/eldoc.el b/lisp/emacs-lisp/eldoc.el
index c95540e..a02406a 100644
--- a/lisp/emacs-lisp/eldoc.el
+++ b/lisp/emacs-lisp/eldoc.el
@@ -100,7 +100,7 @@ If the value is a positive number, it is used to calculate a
 number of logical lines of documentation that ElDoc is allowed to
 put in the echo area.  If a positive integer, the number is used
 directly, while a float specifies the number of lines as a
-proporting of the echo area frame's height.
+proportion of the echo area frame's height.
 
 If value is the symbol `truncate-sym-name-if-fit' t, the part of
 the doc string that represents a symbol's name may be truncated
@@ -692,7 +692,7 @@ following values are allowed:
 
 - `eldoc-documentation-compose-eagerly': calls all functions in
   the special hook and display as many of the resulting doc
-  strings as possible, as soon as possibl.  Preserving the
+  strings as possible, as soon as possible.  Preserving the
   relative order of doc strings;
 
 - `eldoc-documentation-enthusiast': calls all functions in the
diff --git a/lisp/emacs-lisp/pcase.el b/lisp/emacs-lisp/pcase.el
index d3928fa..c7288b7 100644
--- a/lisp/emacs-lisp/pcase.el
+++ b/lisp/emacs-lisp/pcase.el
@@ -642,7 +642,7 @@ MATCH is the pattern that needs to be matched, of the form:
 
 (defun pcase--split-pred (vars upat pat)
   "Indicate the overlap or mutual-exclusion between UPAT and PAT.
-More specifically retuns a pair (A . B) where A indicates whether PAT
+More specifically returns a pair (A . B) where A indicates whether PAT
 can match when UPAT has matched, and B does the same for the case
 where UPAT failed to match.
 A and B can be one of:
@@ -784,7 +784,7 @@ Otherwise, it defers to REST which is a list of branches of 
the form
 \(ELSE-MATCH ELSE-CODE . ELSE-VARS)."
   ;; Depending on the order in which we choose to check each of the MATCHES,
   ;; the resulting tree may be smaller or bigger.  So in general, we'd want
-  ;; to be careful to chose the "optimal" order.  But predicate
+  ;; to be careful to choose the "optimal" order.  But predicate
   ;; patterns make this harder because they create dependencies
   ;; between matches.  So we don't bother trying to reorder anything.
   (cond
diff --git a/lisp/gnus/gnus-search.el b/lisp/gnus/gnus-search.el
index d7b1c06..339bff9 100644
--- a/lisp/gnus/gnus-search.el
+++ b/lisp/gnus/gnus-search.el
@@ -365,7 +365,7 @@ This variable can also be set per-server."
   "A list of strings representing expandable search keys.
 \"Expandable\" simply means the key can be abbreviated while
 typing in search queries, ie \"subject\" could be entered as
-\"subj\" or even \"su\", though \"s\" is ambigous between
+\"subj\" or even \"su\", though \"s\" is ambiguous between
 \"subject\" and \"since\".
 
 Ambiguous abbreviations will raise an error."
@@ -402,7 +402,7 @@ The search \"language\" is essentially a series of key:value
 expressions.  Key is most often a mail header, but there are
 other keys.  Value is a string, quoted if it contains spaces.
 Key and value are separated by a colon, no space.  Expressions
-are implictly ANDed; the \"or\" keyword can be used to
+are implicitly ANDed; the \"or\" keyword can be used to
 OR. \"not\" will negate the following expression, or keys can be
 prefixed with a \"-\".  The \"near\" operator will work for
 engines that understand it; other engines will convert it to
@@ -448,7 +448,7 @@ auto-completion of contact names and addresses for keys like
 Date values (any key in `gnus-search-date-keys') can be provided
 in any format that `parse-time-string' can parse (note that this
 can produce weird results).  Dates with missing bits will be
-interpreted as the most recent occurance thereof (ie \"march 03\"
+interpreted as the most recent occurence thereof (ie \"march 03\"
 is the most recent March 3rd).  Lastly, relative specifications
 such as 1d (one day ago) are understood.  This also accepts w, m,
 and y.  m is assumed to be 30 days.
@@ -646,7 +646,7 @@ gnus-*-mark marks, and return an appropriate string."
   "Return a string from the current buffer.
 If DELIMITED is non-nil, assume the next character is a delimiter
 character, and return everything between point and the next
-occurance of the delimiter, including the delimiters themselves.
+occurence of the delimiter, including the delimiters themselves.
 If TRIM is non-nil, do not return the delimiters. Otherwise,
 return one word."
   ;; This function cannot handle nested delimiters, as it's not a
@@ -789,7 +789,7 @@ the files in ARTLIST by that search key.")
    (raw-queries-p
     :initform (symbol-value 'gnus-search-imap-raw-queries-p)))
     :documentation
-  "The base IMAP search engine, using an IMAP server's search capabilites.
+  "The base IMAP search engine, using an IMAP server's search capabilities.
 This backend may be subclassed to handle particular IMAP servers'
 quirks.")
 
@@ -1082,7 +1082,7 @@ Responsible for handling and, or, and parenthetical 
expressions.")
 (cl-defmethod gnus-search-imap-search-command ((engine gnus-search-imap)
                                               (query string))
   "Create the IMAP search command for QUERY.
-Currenly takes into account support for the LITERAL+ capability.
+Currently takes into account support for the LITERAL+ capability.
 Other capabilities could be tested here."
   (with-slots (literal-plus) engine
     (when literal-plus
@@ -1672,8 +1672,8 @@ and \"-\" before marks."
 (cl-defmethod gnus-search-transform-expression ((engine gnus-search-mairix)
                                                (expr (head or)))
   "Handle Mairix \"or\" statement.
-Mairix only accepts \"or\" expressions on homogenous keys.  We
-cast \"or\" expressions on heterogenous keys as \"and\", which
+Mairix only accepts \"or\" expressions on homogeneous keys.  We
+cast \"or\" expressions on heterogeneous keys as \"and\", which
 isn't quite right, but it's the best we can do.  For date keys,
 only keep one of the terms."
   (let ((term1 (caadr expr))
diff --git a/lisp/gnus/nnselect.el b/lisp/gnus/nnselect.el
index fffa2d2..1daa8aa 100644
--- a/lisp/gnus/nnselect.el
+++ b/lisp/gnus/nnselect.el
@@ -33,7 +33,7 @@
 ;; turn be a vector of three elements: a real prefixed group name, an
 ;; article number in that group, and an integer score.  The score is
 ;; not used by nnselect but may be used by other code to help in
-;; sorting.  Most functions will just chose a fixed number, such as
+;; sorting.  Most functions will just choose a fixed number, such as
 ;; 100, for this score.
 
 ;; For example the search function `gnus-search-run-query' applied to
diff --git a/lisp/isearch.el b/lisp/isearch.el
index c571ea9..8266c4b 100644
--- a/lisp/isearch.el
+++ b/lisp/isearch.el
@@ -3356,7 +3356,7 @@ the word mode."
 
 (defun isearch-lazy-count-format (&optional suffix-p)
   "Format the current match number and the total number of matches.
-When SUFFIX-P is non-nil, the returned string is indended for
+When SUFFIX-P is non-nil, the returned string is intended for
 isearch-message-suffix prompt.  Otherwise, for isearch-message-prefix."
   (let ((format-string (if suffix-p
                            lazy-count-suffix-format
diff --git a/lisp/mh-e/mh-show.el b/lisp/mh-e/mh-show.el
index 9ad843c..1d25b14 100644
--- a/lisp/mh-e/mh-show.el
+++ b/lisp/mh-e/mh-show.el
@@ -136,7 +136,7 @@ displayed."
         (show-window (get-buffer-window mh-show-buffer))
         (display-mime-buttons-flag mh-display-buttons-for-inline-parts-flag))
     (if (not (eq (next-window (minibuffer-window)) (selected-window)))
-        (delete-other-windows))         ; force ourself to the top window
+        (delete-other-windows))         ; force ourselves to the top window
     (mh-in-show-buffer (mh-show-buffer)
       (setq mh-display-buttons-for-inline-parts-flag display-mime-buttons-flag)
       (if (and show-window
diff --git a/lisp/net/dictionary-connection.el 
b/lisp/net/dictionary-connection.el
index 8ad4fe4..8312574 100644
--- a/lisp/net/dictionary-connection.el
+++ b/lisp/net/dictionary-connection.el
@@ -23,9 +23,9 @@
 ;;; Commentary:
 
 ;; dictionary-connection allows to handle TCP-based connections in
-;; client mode where text-based information are exchanged.  There is
+;; client mode where text-based information is exchanged.  There is
 ;; special support for handling CR LF (and the usual CR LF . CR LF
-;; terminater).
+;; terminator).
 
 ;;; Code:
 
@@ -68,7 +68,7 @@
 
 (defun dictionary-connection-open (server port)
   "Open a connection to SERVER at PORT.
-A data structure identifing the connection is returned"
+A data structure identifying the connection is returned"
 
   (let ((process-buffer (generate-new-buffer (format " connection to %s:%s"
                                                     server
diff --git a/lisp/net/dictionary.el b/lisp/net/dictionary.el
index 6f08605..c6af4e6 100644
--- a/lisp/net/dictionary.el
+++ b/lisp/net/dictionary.el
@@ -127,9 +127,9 @@ by the choice value:
 
   The found word exactly matches the searched word.
 
-- Similiar sounding
+- Similar sounding
 
-  The found word sounds similiar to the searched word.  For this match type
+  The found word sounds similar to the searched word.  For this match type
   the soundex algorithm defined by Donald E. Knuth is used.  It will only
   works with english words and the algorithm is not very reliable (i.e.,
   the soundex algorithm is quite simple).
@@ -148,7 +148,7 @@ by the choice value:
   dictionary server."
   :group 'dictionary
   :type '(choice (const :tag "Exact match" "exact")
-                (const :tag "Similiar sounding" "soundex")
+                (const :tag "Similar sounding" "soundex")
                 (const :tag "Levenshtein distance one" "lev")
                 (string :tag "User choice"))
   :version "28.1")
@@ -419,7 +419,7 @@ This is a quick reference to this mode describing the 
default key bindings:
 
 ;;;###autoload
 (defun dictionary ()
-  "Create a new dictonary buffer and install `dictionary-mode'."
+  "Create a new dictionary buffer and install `dictionary-mode'."
   (interactive)
   (let ((buffer (or (and dictionary-use-single-buffer
                          (get-buffer "*Dictionary*"))
@@ -568,7 +568,7 @@ The connection takes the proxy setting in customization 
group
       answer)))
 
 (defun dictionary-split-string (string)
-  "Split STRING constiting of space-separated words into elements.
+  "Split STRING consisting of space-separated words into elements.
 This function knows about the special meaning of quotes (\")"
   (let ((list))
     (while (and string (> (length string) 0))
@@ -894,7 +894,7 @@ The word is taken from the buffer, the DICTIONARY is given 
as argument."
       (unless (dictionary-check-reply reply 110)
        (error "Unknown server answer: %s"
               (dictionary-reply reply)))
-      (dictionary-display-dictionarys))))
+      (dictionary-display-dictionaries))))
 
 (defun dictionary-simple-split-string (string &optional pattern)
   "Return a list of substrings of STRING which are separated by PATTERN.
@@ -909,7 +909,7 @@ If PATTERN is omitted, it defaults to \"[ 
\\f\\t\\n\\r\\v]+\"."
            start (match-end 0)))
     (nreverse (cons (substring string start) parts))))
 
-(defun dictionary-display-dictionarys ()
+(defun dictionary-display-dictionaries ()
   "Handle the display of all dictionaries existing on the server."
   (dictionary-pre-buffer)
   (insert "Please select your default dictionary:\n\n")
@@ -1171,7 +1171,7 @@ allows editing it."
   ;; if called by pressing the button
   (unless word
     (setq word (read-string "Search word: " nil 'dictionary-word-history)))
-  ;; just in case non-interactivly called
+  ;; just in case non-interactively called
   (unless dictionary
     (setq dictionary dictionary-default-dictionary))
   (dictionary-new-search (cons word dictionary)))
@@ -1249,10 +1249,10 @@ allows editing it."
 
 ;;; Tooltip support
 
-;; Add a mode indicater named "Dict"
+;; Add a mode indicator named "Dict"
 (defvar dictionary-tooltip-mode
   nil
-  "Indicates wheather the dictionary tooltip mode is active.")
+  "Indicates whether the dictionary tooltip mode is active.")
 (nconc minor-mode-alist '((dictionary-tooltip-mode " Dict")))
 
 (defcustom dictionary-tooltip-dictionary
diff --git a/lisp/net/eudcb-macos-contacts.el b/lisp/net/eudcb-macos-contacts.el
index 66a684d..b07016c 100644
--- a/lisp/net/eudcb-macos-contacts.el
+++ b/lisp/net/eudcb-macos-contacts.el
@@ -108,7 +108,7 @@ RETURN-ATTRS is a list of attributes to return, defaulting 
to
 (defun eudc-macos-contacts-set-server (dummy)
   "Set the EUDC server to macOS Contacts app.
 The server in DUMMY is not actually used, since this backend
-always and implicitly connetcs to an instance of the Contacts app
+always and implicitly connects to an instance of the Contacts app
 running on the local host."
   (interactive)
   (eudc-set-server dummy 'macos-contacts)
diff --git a/lisp/net/mailcap.el b/lisp/net/mailcap.el
index b95cd0f..3097c9a 100644
--- a/lisp/net/mailcap.el
+++ b/lisp/net/mailcap.el
@@ -332,7 +332,7 @@ whose car is a symbol, it is `eval'uated to yield the 
validity.  If it
 is a string or list of strings, it represents a shell command to run
 to return a true or false shell value for the validity.
 
-The last matching entry in this structure takes presedence over
+The last matching entry in this structure takes precedence over
 preceding entries.")
 (put 'mailcap-mime-data 'risky-local-variable t)
 
diff --git a/lisp/net/tramp-smb.el b/lisp/net/tramp-smb.el
index 4519c34..6935955 100644
--- a/lisp/net/tramp-smb.el
+++ b/lisp/net/tramp-smb.el
@@ -1928,7 +1928,7 @@ If ARGUMENT is non-nil, use it as argument for
 
     ;; Check whether we still have the same smbclient version.
     ;; Otherwise, we must delete the connection cache, because
-    ;; capabilities migh have changed.
+    ;; capabilities might have changed.
     (unless (or argument (processp p))
       (let ((default-directory (tramp-compat-temporary-file-directory))
            (command (concat tramp-smb-program " -V")))
diff --git a/lisp/nxml/nxml-mode.el b/lisp/nxml/nxml-mode.el
index 0602943..1bc905c 100644
--- a/lisp/nxml/nxml-mode.el
+++ b/lisp/nxml/nxml-mode.el
@@ -546,7 +546,7 @@ Many aspects this mode can be customized using
     (when (and nxml-default-buffer-file-coding-system
               (not (local-variable-p 'buffer-file-coding-system)))
       (setq buffer-file-coding-system nxml-default-buffer-file-coding-system))
-    ;; When starting a new file, insert the XML declaraction.
+    ;; When starting a new file, insert the XML declaration.
     (when (and nxml-auto-insert-xml-declaration-flag
                (zerop (buffer-size)))
       (nxml-insert-xml-declaration)))
diff --git a/lisp/progmodes/cc-engine.el b/lisp/progmodes/cc-engine.el
index 484624b..9038c7b 100644
--- a/lisp/progmodes/cc-engine.el
+++ b/lisp/progmodes/cc-engine.el
@@ -2665,7 +2665,7 @@ comment at the start of cc-engine.el for more info."
 ;; One of the above "near" caches is associated with each of these functions.
 ;;
 ;; When searching this cache, these functions first seek an exact match, then
-;; a "close" match from the assiciated near cache.  If neither of these
+;; a "close" match from the associated near cache.  If neither of these
 ;; succeed, the nearest preceding entry in the far cache is used.
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
diff --git a/lisp/progmodes/flymake.el b/lisp/progmodes/flymake.el
index b8c8a82..d018032 100644
--- a/lisp/progmodes/flymake.el
+++ b/lisp/progmodes/flymake.el
@@ -483,7 +483,7 @@ Currently, Flymake may provide these keyword-value pairs:
 
 * `:recent-changes', a list of recent changes since the last time
   the backend function was called for the buffer.  An empty list
-  indicates that no changes have been reocrded.  If it is the
+  indicates that no changes have been recorded.  If it is the
   first time that this backend function is called for this
   activation of `flymake-mode', then this argument isn't provided
   at all (i.e. it's not merely nil).
diff --git a/lisp/progmodes/verilog-mode.el b/lisp/progmodes/verilog-mode.el
index f934ef7..55c04e1 100644
--- a/lisp/progmodes/verilog-mode.el
+++ b/lisp/progmodes/verilog-mode.el
@@ -134,7 +134,7 @@
   (interactive)
   (message "Using verilog-mode version %s" verilog-mode-version))
 
-(defmacro verilog--supressed-warnings (warnings &rest body)
+(defmacro verilog--suppressed-warnings (warnings &rest body)
   (declare (indent 1) (debug t))
   (cond
    ((fboundp 'with-suppressed-warnings)
@@ -5550,7 +5550,7 @@ FILENAME to find directory to run in, or defaults to 
`buffer-file-name'."
           ;; font-lock-fontify-buffer, but IIUC the problem this is supposed to
           ;; solve only appears in Emacsen older than font-lock-ensure anyway.
           (when fontlocked
-            (verilog--supressed-warnings
+            (verilog--suppressed-warnings
                 ((interactive-only font-lock-fontify-buffer))
               (font-lock-fontify-buffer))))))))
 
diff --git a/lisp/simple.el b/lisp/simple.el
index d6ccdad..a4da3f5 100644
--- a/lisp/simple.el
+++ b/lisp/simple.el
@@ -549,7 +549,7 @@ It must be called via `run-hook-with-args-until-success' 
with no arguments.
 If any function on this hook returns a non-nil value, `delete-selection-mode'
 will act on that value (see `delete-selection-helper') and will
 usually delete the region.  If all the functions on this hook return
-nil, it is an indiction that `self-insert-command' needs the region
+nil, it is an indication that `self-insert-command' needs the region
 untouched by `delete-selection-mode' and will itself do whatever is
 appropriate with the region.
 Any function on `post-self-insert-hook' that acts on the region should
diff --git a/lisp/textmodes/bibtex.el b/lisp/textmodes/bibtex.el
index a22cd97..301f701 100644
--- a/lisp/textmodes/bibtex.el
+++ b/lisp/textmodes/bibtex.el
@@ -3327,7 +3327,7 @@ Use `bibtex-summary-function' to generate summary."
         (message "%s %s" key summary))))))
 
 (defun bibtex-copy-summary-as-kill (&optional arg)
-  "Push summery of current BibTeX entry to kill ring.
+  "Push summary of current BibTeX entry to kill ring.
 Use `bibtex-summary-function' to generate summary.
 If prefix ARG is non-nil push BibTeX entry's URL to kill ring
 that is generated by calling `bibtex-url'."
diff --git a/lisp/textmodes/texnfo-upd.el b/lisp/textmodes/texnfo-upd.el
index ea35641..04778ee 100644
--- a/lisp/textmodes/texnfo-upd.el
+++ b/lisp/textmodes/texnfo-upd.el
@@ -1033,7 +1033,7 @@ However, there does not need to be a title field."
 
   (save-excursion
     ;; `master-menu-inserted-p' is a kludge to tell
-    ;; whether to insert @end detailmenu (see bleow)
+    ;; whether to insert @end detailmenu (see below)
     (let (master-menu-inserted-p)
       ;; Handle top of menu
       (insert "\n@menu\n")
diff --git a/src/dispnew.c b/src/dispnew.c
index e603c67..b3e4587 100644
--- a/src/dispnew.c
+++ b/src/dispnew.c
@@ -3328,7 +3328,7 @@ update_frame_with_menu (struct frame *f, int row, int col)
 }
 
 /* Update the mouse position for a frame F.  This handles both
-   updating the display for mouse-face propreties and updating the
+   updating the display for mouse-face properties and updating the
    help echo text.
 
    Returns the number of events generated.  */
diff --git a/src/font.c b/src/font.c
index a59ebe2..7c1d1ff 100644
--- a/src/font.c
+++ b/src/font.c
@@ -4122,7 +4122,7 @@ representing the OpenType features supported by the font 
by this form:
 SCRIPT, LANGSYS, and FEATURE are all symbols representing OpenType
 Layout tags.
 
-In addition to the keys listed abobe, the following keys are reserved
+In addition to the keys listed above, the following keys are reserved
 for the specific meanings as below:
 
 The value of :combining-capability is non-nil if the font-backend of
diff --git a/src/indent.c b/src/indent.c
index 0a6b460..6246b54 100644
--- a/src/indent.c
+++ b/src/indent.c
@@ -1315,7 +1315,7 @@ compute_motion (ptrdiff_t from, ptrdiff_t frombyte, 
EMACS_INT fromvpos,
             j        ^---- next after the point
             ^---  next char. after the point.
             ----------
-                     In case of sigle-column character
+                     In case of single-column character
 
             ----------
             abcdefgh\\
diff --git a/src/process.c b/src/process.c
index 3beb9cf..b98bc29 100644
--- a/src/process.c
+++ b/src/process.c
@@ -8255,7 +8255,7 @@ init_process_emacs (int sockfd)
         private SIGCHLD handler, allowing catch_child_signal to copy
         it into lib_child_handler.
 
-         Unfortunatly in glib commit 2e471acf, the behavior changed to
+         Unfortunately in glib commit 2e471acf, the behavior changed to
          always install a signal handler when g_child_watch_source_new
          is called and not just the first time it's called.  Glib also
          now resets signal handlers to SIG_DFL when it no longer has a
diff --git a/src/w32fns.c b/src/w32fns.c
index 86c3db6..9db367b 100644
--- a/src/w32fns.c
+++ b/src/w32fns.c
@@ -3893,7 +3893,7 @@ deliver_wm_chars (int do_translate, HWND hwnd, UINT msg, 
UINT wParam,
                     Essentially, we have no information about the "role" of
                     modifiers on this key: which contribute into the
                     produced character (so "are consumed"), and which are
-                    "extra" (must attache to bindable events).
+                    "extra" (must attach to bindable events).
 
                     The default above would consume ALL modifiers, so the
                     character is reported "as is".  However, on many layouts
diff --git a/test/lisp/jsonrpc-tests.el b/test/lisp/jsonrpc-tests.el
index ea340c3..92306d1 100644
--- a/test/lisp/jsonrpc-tests.el
+++ b/test/lisp/jsonrpc-tests.el
@@ -244,7 +244,7 @@
                        :timeout 1)
       ;; Wait another 0.5 secs just in case the success handlers of
       ;; one of these last two requests didn't quite have a chance to
-      ;; run (Emacs 25.2 apparentely needs this).
+      ;; run (Emacs 25.2 apparently needs this).
       (accept-process-output nil 0.5)
       (should second-deferred-went-through-p)
       (should (eq 1 n-deferred-1))



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/lisp/progmodes/cperl-mode.el b/lisp/progmodes/cperl-mode.el
index 44a7526..d01bd3a 100644
--- a/lisp/progmodes/cperl-mode.el
+++ b/lisp/progmodes/cperl-mode.el
@@ -1764,12 +1764,12 @@ or as help on variables `cperl-tips', `cperl-problems',
     (setq-local syntax-propertize-function
                 (lambda (start end)
                   (goto-char start)
                   ;; Even if cperl-fontify-syntaxically has already gone
                   ;; beyond `start', syntax-propertize has just removed
                   ;; syntax-table properties between start and end, so we have
                   ;; to re-apply them.
                   (setq cperl-syntax-done-to start)
-                  (cperl-fontify-syntaxically end))))
+                  (cperl-fontify-syntactically end))))
   (setq cperl-font-lock-multiline t) ; Not localized...
   (setq-local font-lock-multiline t)
   (setq-local font-lock-fontify-region-function
@@ -8407,7 +8407,7 @@ do extra unwind via `cperl-unwind-to-safe'."
     (setq end (point)))
   (font-lock-default-fontify-region beg end loudly))
 
-(defun cperl-fontify-syntaxically (end)
+(defun cperl-fontify-syntactically (end)
   ;; Some vars for debugging only
   ;; (message "Syntaxifying...")
   (let ((dbg (point)) (iend end) (idone cperl-syntax-done-to)
@@ -1764,12 +1764,12 @@ or as help on variables `cperl-tips', `cperl-problems',
                 (lambda (start end)
                   (goto-char start)
-                  ;; Even if cperl-fontify-syntaxically has already gone
+                  ;; Even if cperl-fontify-syntactically has already gone
                   ;; beyond `start', syntax-propertize has just removed
                   ;; syntax-table properties between start and end, so we have